@@ -2,8 +2,8 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Config;
-$App::ClusterSSH::Config::VERSION = '4.18_01'; # TRIAL
-$App::ClusterSSH::Config::VERSION = '4.1801';
+$App::ClusterSSH::Config::VERSION = '4.18_03'; # TRIAL
+$App::ClusterSSH::Config::VERSION = '4.1803';
 # ABSTRACT: ClusterSSH::Config - Object representing application configuration
 
 =head1 SYNOPSIS
@@ -38,6 +38,7 @@ my %default_config = (
     terminal_bg_style          => 'dark',
     terminal_allow_send_events => "-xrm '*.VT100.allowSendEvents:true'",
     terminal_font              => "6x13",
+    main_window_font           => "",
     terminal_size              => "80x24",
 
     use_hotkeys             => "yes",
@@ -294,6 +295,8 @@ sub parse_config_file {
     # tidy up entries, just in case
     $read_config{terminal_font} =~ s/['"]//g
         if ( $read_config{terminal_font} );
+    $read_config{main_window_font} =~ s/['"]//g
+        if ( $read_config{main_window_font} );
 
     $self->validate_args(%read_config);
 
