@@ -2,8 +2,8 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Getopt;
-$App::ClusterSSH::Getopt::VERSION = '4.18_01'; # TRIAL
-$App::ClusterSSH::Getopt::VERSION = '4.1801';
+$App::ClusterSSH::Getopt::VERSION = '4.18_03'; # TRIAL
+$App::ClusterSSH::Getopt::VERSION = '4.1803';
 # ABSTRACT: App::ClusterSSH::Getopt - module to process command line args
 
 =head1 SYNOPSIS
@@ -197,6 +197,13 @@ sub add_common_options {
             'Specify the font to use in the terminal windows. Use standard X font notation such as "5x8".'
         ),
     );
+    $self->add_option(
+        spec     => 'main-window-font|M=s',
+        arg_desc => 'font',
+        help     => $self->loc(
+            'Specify the font to use in the main console window. Use Tk font notation such as "sans 14 bold".'
+        ),
+    );
     $self->add_option(
         spec => 'list|L:s',
         help => $self->loc(
@@ -392,6 +399,8 @@ sub getopts {
         if ( $self->can('username') && $self->username );
 
     $self->parent->config->{terminal_font} = $self->font if ( $self->font );
+    $self->parent->config->{main_window_font} = $self->main_window_font
+        if ( $self->main_window_font );
     $self->parent->config->{terminal_args} = $self->term_args
         if ( $self->term_args );
 
@@ -959,6 +968,11 @@ B<NOTE:> Any "generic" change to the method (e.g., specifying the ssh port to us
         q{Font to use in the terminal windows.  Use standard X font notation.}
     );
 
+    output '=item main_window_font = ""';
+    output $self->loc(
+        q{Font to use in the main console window.  Use Tk font notation (e.g. "sans 14 bold").  When empty, the default is used (on 4K+ displays, Nimbus 14).}
+    );
+
     output '=item terminal_reserve_top = 5';
     output '=item terminal_reserve_bottom = 0';
     output '=item terminal_reserve_left = 5';
