@@ -2,8 +2,8 @@ use strict;
 use warnings;
 
 package App::ClusterSSH::Window::Tk;
-$App::ClusterSSH::Window::Tk::VERSION = '4.18_01'; # TRIAL
-$App::ClusterSSH::Window::Tk::VERSION = '4.1801';
+$App::ClusterSSH::Window::Tk::VERSION = '4.18_03'; # TRIAL
+$App::ClusterSSH::Window::Tk::VERSION = '4.1803';
 # ABSTRACT: Object for creating windows using Tk
 
 use English qw( -no_match_vars );
@@ -1288,8 +1288,12 @@ sub create_windows() {
 
     $windows{main_window}
         = MainWindow->new( -title => "ClusterSSH", -class => 'cssh', );
-    if ( $screen_height * $screen_width >= 8294400 )    # display 4k or bigger
-    {
+    if ( $self->config->{main_window_font} ) {
+        $windows{main_window}
+            ->optionAdd( '*font', $self->config->{main_window_font} );
+    }
+    elsif ( $screen_height * $screen_width >= 8294400 )
+    {    # display 4k or bigger
         $windows{main_window}->optionAdd( '*font', 'Nimbus 14' )
             ;    # better for 4k displays
     }
@@ -1357,10 +1361,16 @@ sub create_windows() {
             $menus{entrytext} = "";
             my $paste_text = '';
 
-            # SelectionGet is fatal if no selection is given
+# SelectionGet is fatal if no selection is given; try PRIMARY then CLIPBOARD (Wayland/WSLg use CLIPBOARD)
             Tk::catch {
                 $paste_text = $windows{main_window}->SelectionGet;
             };
+            if ( !length($paste_text) ) {
+                Tk::catch {
+                    $paste_text = $windows{main_window}
+                        ->SelectionGet( -selection => 'CLIPBOARD' );
+                };
+            }
 
             if ( !length($paste_text) ) {
                 warn("Got empty paste event\n");
